pub enum CrashLogSource {
Acpi,
PmtDevice(PmtDeviceId),
EventLog,
}Expand description
Represents a source from which Crash Log data can be extracted
Each source support different type of capabilities, which are represented as Capabilities
Variants
Acpi
ACPI BERT table
PmtDevice(PmtDeviceId)
Intel PMT device that exposes a Crash Log region
EventLog
OS Event Log
Implementations
Sourceimpl CrashLogSource
impl CrashLogSource
Sourcepub fn discover() -> Vec<Self>
👎Deprecated since 1.2.0: use discover_all_sources or discover_distinct instead
pub fn discover() -> Vec<Self>
use discover_all_sources or discover_distinct instead
Returns all the Crash Log sources that are available in the platform
Sourcepub fn discover_all_sources() -> Vec<Self>
pub fn discover_all_sources() -> Vec<Self>
Returns all the Crash Log sources that are available in the platform
Sourcepub fn discover_distinct() -> Vec<Self>
pub fn discover_distinct() -> Vec<Self>
Returns all the Crash Log sources that are available in the platform without duplicates
Sourcepub fn extract(&self) -> Result<Vec<CrashLog>, Error>
pub fn extract(&self) -> Result<Vec<CrashLog>, Error>
Returns the Crash Log extracted from the platform using the current Crash Log source
Sourcepub fn trigger(&self) -> Result<(), Error>
pub fn trigger(&self) -> Result<(), Error>
Triggers an on-demand Crash Log collection on this source
Sourcepub fn description(&self) -> String
pub fn description(&self) -> String
Returns a human readable description of the Crash Log source
Sourcepub fn capabilities(&self) -> Capabilities
pub fn capabilities(&self) -> Capabilities
Returns all the capabilities of the Crash Log Source