CrashLogSource

Enum CrashLogSource 

pub enum CrashLogSource {
    Acpi,
    PmtDevice(PmtDeviceId),
    EventLog,
}
Represents a source from which Crash Log data can be extracted

Each source support different type of capabilities, which are represented as Capabilities

Variants



Acpi

ACPI BERT table



PmtDevice(PmtDeviceId)

Intel PMT device that exposes a Crash Log region



EventLog

OS Event Log

Implementations

Source

impl CrashLogSource

pub fn discover() -> Vec<Self>

Returns all the Crash Log sources that are available in the platform

pub fn extract(&self) -> Result<Vec<CrashLog>, Error>

Returns the Crash Log extracted from the platform using the current Crash Log source

pub fn trigger(&self) -> Result<(), Error>

Triggers an on-demand Crash Log collection on this source

pub fn clear(&self) -> Result<(), Error>

Clears the Crash Log storage on this source

pub fn enable(&self) -> Result<(), Error>

Enable the Crash Log collection on this source

pub fn disable(&self) -> Result<(), Error>

Disable the Crash Log collection on this source

pub fn description(&self) -> String

Returns a human readable description of the Crash Log source

pub fn capabilities(&self) -> Capabilities

Returns all the capabilities of the Crash Log Source